# Generated by Django 4.2.17 on 2024-12-08 05:13

import baykeshop.db.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='baykeshopuser',
            name='mobile',
            field=models.CharField(blank=True, max_length=11, null=True, unique=True, validators=[baykeshop.db.validators.validate_phone], verbose_name='手机号码'),
        ),
        migrations.AlterField(
            model_name='baykeshopuseraddress',
            name='phone',
            field=models.CharField(max_length=50, validators=[baykeshop.db.validators.validate_phone], verbose_name='手机'),
        ),
    ]
