{% load i18n baykeshop %}
<a class="bk-box" href="{% url 'shop:detail' spu.id %}">
    <figure class="bk-image bk-is-1by1">
        <img src="{{ MEDIA_URL }}{{ spu.image_url }}" alt="{{ spu.name  }}" />
    </figure>
    <h1 class="py-2" title="{{ spu.name }}">
        {{ spu.name|truncatechars:15 }}
    </h1>
    <div class="">
        <span class="bk-is-size-4 bk-has-text-danger bk-has-text-weight-bold">￥{{ spu.price|floatformat:"-2g" }}</span>
        <div class="bk-is-flex bk-is-justify-content-space-between bk-has-text-grey">
            <span>{{ spu.sales }}{% translate '人付款' %}</span>
            <span>{% score_avg spu %}{% translate '分' %}</span>
        </div>
    </div>
</a>