{% load i18n baykeconfig %}
<footer class="bk-footer bk-has-background-black-ter bk-has-text-grey-light">
    <div class="bk-container">
        <div class="bk-fixed-grid bk-has-5-cols-desktop bk-has-1-cols-mobile">
            <div class="bk-grid">
                <div class="bk-cell">
                    <div class="bk-is-flex bk-is-justify-content-center">
                        <span class="bk-icon bk-is-large bk-has-text-grey-light mr-1" style="font-size: 3em;">
                            <i class="mdi mdi-basket-plus"></i>
                        </span>
                        <div class="bk-has-text-grey-light">
                            <p class="bk-heading bk-is-size-6">轻松购物</p>
                            <p class="bk-title bk-has-text-grey-light bk-is-size-5">品种齐全</p>
                        </div>
                    </div>
                </div>
                <div class="bk-cell">
                    <div class="bk-is-flex bk-is-justify-content-center">
                        <span class="bk-icon bk-is-large bk-has-text-grey-light mr-1" style="font-size: 3em;">
                            <i class="mdi mdi-shield-car"></i>
                        </span>
                        <div class="bk-has-text-grey-light">
                            <p class="bk-heading bk-is-size-6">多仓直发</p>
                            <p class="bk-title bk-has-text-grey-light bk-is-size-5">极速配送</p>
                        </div>
                    </div>
                </div>
                <div class="bk-cell">
                    <div class="bk-is-flex bk-is-justify-content-center">
                        <span class="bk-icon bk-is-large bk-has-text-grey-light mr-1" style="font-size: 3em;">
                            <i class="mdi mdi-ballot"></i>
                        </span>
                        <div class="bk-has-text-grey-light">
                            <p class="bk-heading bk-is-size-6">精致服务</p>
                            <p class="bk-title bk-has-text-grey-light bk-is-size-5">正品行货</p>
                        </div>
                    </div>
                </div>
                <div class="bk-cell">
                    <div class="bk-is-flex bk-is-justify-content-center">
                        <span class="bk-icon bk-is-large bk-has-text-grey-light mr-1" style="font-size: 3em;">
                            <i class="mdi mdi-wallet-giftcard"></i>
                        </span>
                        <div class="bk-has-text-grey-light">
                            <p class="bk-heading bk-is-size-6">畅选无忧</p>
                            <p class="bk-title bk-has-text-grey-light bk-is-size-5">天天低价</p>
                        </div>
                    </div>
                </div>
                <div class="bk-cell">
                    <div class="bk-is-flex bk-is-justify-content-center">
                        <span class="bk-icon bk-is-large bk-has-text-grey-light mr-1" style="font-size: 3em;">
                            <i class="mdi mdi-hand-heart"></i>
                        </span>
                        <div class="bk-has-text-grey-light">
                            <p class="bk-heading bk-is-size-6">极速退换</p>
                            <p class="bk-title bk-has-text-grey-light bk-is-size-5">无忧售后</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="bk-dropdown-divider bk-has-background-grey-dark"></div>
        <div class="bk-has-text-centered">
            
            <p class="bk-is-size-5">{% dict_value 'COPYRIGHT' %}</p>
            <p class="bk-has-text-grey-light mt-3">
                <a class="bk-has-text-grey-light" href=""><span>{% dict_value 'ICP' %}</span></a>
                <!-- / <a class="bk-has-text-grey-light" href="">SiteMap</a>  -->
            </p>
        </div>
    </div>
</footer>