<div class="bk-box p-6">
    <h1 class="bk-title bk-is-5"">
        <span class="bk-icon">
            <i class="mdi mdi-archive-check-outline"></i>
        </span>
        <span>{{ sidebar.name }}</span> 
    </h1>
    <hr>
    <aside class="bk-menu px-2">
        
        <ul class="bk-menu-list">
            {% for item in sidebar.archive %}
                <li>
                    <a href="{% url 'article:archive' item.year item.month %}">
                        <span>{{ item }}</span>
                    </a>
                </li>
            {% endfor %}
        </ul>
    </aside>
</div>