{% extends 'baykeshop/member/address_form.html' %}

{% load i18n %}

{% block profile_header %}
    <h1 class="bk-is-size-4">
        <span class="bk-icon"><i class="mdi mdi-account-edit-outline"></i></span>
        {% translate '修改用户信息' %}
    </h1>
{% endblock %}